pub trait FrameCodec<'a>: FrameRead<'a, Error = <Self as FrameWrite>::Error> + FrameWrite { }Expand description
Composite trait for types that implement both FrameRead and FrameWrite
with the same error type.
A blanket impl covers all types satisfying both bounds - there is no need to implement this trait manually.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".