FrameCodec

Trait FrameCodec 

pub trait FrameCodec<'a>: FrameRead<'a, Error = <Self as FrameWrite>::Error> + FrameWrite { }
Composite trait for types that implement both FrameRead and FrameWrite with the same error type.

A blanket impl covers all types satisfying both bounds - there is no need to implement this trait manually.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<'a, T> FrameCodec<'a> for T
where T: FrameRead<'a> + FrameWrite + FrameRead<'a, Error = <T as FrameWrite>::Error>,